
# Slot: catalyst qualifier


a qualifier that connects an association between two causally connected entities (for example, two chemical entities, or a chemical entity in that changes location) and the gene product, gene, or complex that enables or catalyzes the change.

URI: [biolink:catalyst_qualifier](https://w3id.org/biolink/vocab/catalyst_qualifier)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..\*</sub> [MacromolecularMachineMixin](MacromolecularMachineMixin.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children

 *  [chemical to chemical derivation association➞catalyst qualifier](chemical_to_chemical_derivation_association_catalyst_qualifier.md)

## Used by

